@@ -115,7 +115,8 @@ var Geoclue = GObject.registerClass({
 
     _updateLocation(location) {
         if (!this.place)
-            this.place = new Place.Place({ name: _("Current location") });
+            this.place = new Place.Place({ name: _("Current location"),
+                                           isCurrentLocation: true });
 
         this.place.location = location;
         this.emit('location-changed');
