@@ -22,6 +22,7 @@ const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const Gdk = imports.gi.Gdk;
 
+const Application = imports.application;
 const MapSource = imports.mapSource;
 const MapView = imports.mapView;
 const Service = imports.service;
@@ -64,6 +65,7 @@ var LayersPopover = GObject.registerClass({
                         'aerialLayerButton',
                         'streetLayerImage',
                         'aerialLayerImage',
+                        'hybridAerialRevealer',
                         'layersListBox',
                         'loadLayerButton' ]
 }, class LayersPopover extends Gtk.Popover {
@@ -97,13 +99,30 @@ var LayersPopover = GObject.registerClass({
                 source: MapSource.createStreetSource(),
                 widget: this._streetLayerImage,
                 lastLocation: { x: -1, y: -1, z: -1 }
-            },
-            aerial: {
+            }
+        };
+
+        if (Service.getService().tiles.streetDark) {
+            this._layerPreviews.streetDark = {
+                source: MapSource.createStreetDarkSource(),
+                widget: this._streetLayerImage,
+                lastLocation: { x: -1, y: -1, z: -1 }
+            };
+        }
+        if (Service.getService().tiles.aerial) {
+            this._layerPreviews.aerial = {
                 source: MapSource.createAerialSource(),
                 widget: this._aerialLayerImage,
                 lastLocation: { x: -1, y: -1, z: -1 }
-            }
-        };
+            };
+        }
+        if (Service.getService().tiles.hybridAerial) {
+            this._layerPreviews.hybridAerial = {
+                source: MapSource.createHybridAerialSource(),
+                widget: this._aerialLayerImage,
+                lastLocation: { x: -1, y: -1, z: -1 }
+            };
+        }
 
         // disable the map type switch buttons if aerial is unavailable
         if (Service.getService().tiles.aerial) {
@@ -125,6 +144,11 @@ var LayersPopover = GObject.registerClass({
                                        this._setLayerPreviews.bind(this));
             this._mapView.view.connect("notify::longitude",
                                        this._setLayerPreviews.bind(this));
+            Application.settings.connect("changed::night-mode",
+                                         this._onNightModeChanged.bind(this));
+            Application.settings.connect("changed::hybrid-aerial",
+                                         this._onHybridAerialChanged.bind(this));
+
         } else {
             this._streetLayerButton.visible = false;
             this._aerialLayerButton.visible = false;
@@ -136,12 +160,40 @@ var LayersPopover = GObject.registerClass({
         });
     }
 
-    _setLayerPreviews() {
-        this._setLayerPreviewImage("street");
-        this._setLayerPreviewImage("aerial");
+    _onNightModeChanged() {
+        if (Service.getService().tiles.streetDark &&
+            Application.settings.get('night-mode')) {
+            this._setLayerPreviewImage('streetDark', true);
+        } else {
+            this._setLayerPreviewImage('street', true);
+        }
     }
 
-    _setLayerPreviewImage(layer) {
+    _onHybridAerialChanged() {
+        if (Service.getService().tiles.hybridAerial &&
+            Application.settings.get('hybrid-aerial')) {
+            this._setLayerPreviewImage('hybridAerial', true);
+        } else {
+            this._setLayerPreviewImage('aerial', true);
+        }
+    }
+
+    _setLayerPreviews() {
+        if (Service.getService().tiles.streetDark &&
+            Application.settings.get('night-mode')) {
+            this._setLayerPreviewImage('streetDark');
+        } else {
+            this._setLayerPreviewImage('street');
+        }
+        if (Service.getService().tiles.hybridAerial &&
+            Application.settings.get('hybrid-aerial')) {
+            this._setLayerPreviewImage('hybridAerial');
+        } else {
+            this._setLayerPreviewImage('aerial');
+        }
+    }
+
+    _setLayerPreviewImage(layer, forceUpdate = false) {
         let previewInfo = this._layerPreviews[layer];
         let source = previewInfo.source;
         let widget = previewInfo.widget;
@@ -157,7 +209,7 @@ var LayersPopover = GObject.registerClass({
         // then don't bother changing anything
         if (previewInfo.lastLocation.x == x &&
             previewInfo.lastLocation.y == y &&
-            previewInfo.lastLocation.z == z) {
+            previewInfo.lastLocation.z == z && !forceUpdate) {
 
             return;
         }
@@ -188,10 +240,14 @@ var LayersPopover = GObject.registerClass({
     }
 
     setMapType(mapType) {
-        if (mapType === MapView.MapType.STREET)
+        if (mapType === MapView.MapType.STREET) {
             this._streetLayerButton.active = true;
-        else if (mapType === MapView.MapType.AERIAL)
+            this._hybridAerialRevealer.reveal_child = false;
+        } else if (mapType === MapView.MapType.AERIAL) {
             this._aerialLayerButton.active = true;
+            if (Service.getService().tiles.hybridAerial)
+                this._hybridAerialRevealer.reveal_child = true;
+        }
     }
 
     _onRemoveClicked(row) {
