@@ -22,8 +22,8 @@
 
 const Champlain = imports.gi.Champlain;
 const Gio = imports.gi.Gio;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 
 const Place = imports.place;
 const Route = imports.route;
@@ -33,11 +33,10 @@ const RouteQuery = imports.routeQuery;
 const _RLM = '\u200F';
 const _LRM = '\u200E';
 
-var StoredRoute = new Lang.Class({
-    Name: 'StoredRoute',
-    Extends: Place.Place,
+var StoredRoute = GObject.registerClass(
+class StoredRoute extends Place.Place {
 
-    _init: function(params) {
+    _init(params) {
         let route = params.route;
         delete params.route;
 
@@ -71,15 +70,15 @@ var StoredRoute = new Lang.Class({
         if (geoclue)
             currentLocation = geoclue.place;
 
-        places.forEach((function(place) {
+        places.forEach((place) => {
             if (currentLocation && place === currentLocation)
                 this._containsCurrentLocation = true;
 
             this.places.push(new Place.Place({ place: place }));
-        }).bind(this));
+        });
 
-        this.parent(params);
-    },
+        super._init(params);
+    }
 
     get viaString() {
         let directionMarker = this._rtl ? _RLM : _LRM;
@@ -87,11 +86,11 @@ var StoredRoute = new Lang.Class({
         return this.places.map(function(place) {
             return directionMarker + place.name;
         }).join(directionMarker + arrow);
-    },
+    }
 
     get transportation() {
         return this._transportation;
-    },
+    }
 
     get icon() {
         let transport = RouteQuery.Transportation;
@@ -110,17 +109,17 @@ var StoredRoute = new Lang.Class({
         }
 
         return icon;
-    },
+    }
 
     get uniqueID() {
         return this._transportation + '-' + this.places.map(function(place) {
             return [place.osm_type, place.osm_id].join('-');
         }).join('-');
-    },
+    }
 
     get containsCurrentLocation() {
         return this._containsCurrentLocation;
-    },
+    }
 
     get containsNull() {
         let hasNull = false;
@@ -132,9 +131,9 @@ var StoredRoute = new Lang.Class({
             }
         }
         return hasNull;
-    },
+    }
 
-    toJSON: function() {
+    toJSON() {
         let turnPoints = this.route.turnPoints.map(function(turnPoint) {
             let coordinate = { latitude: turnPoint.coordinate.latitude,
                                longitude: turnPoint.coordinate.longitude };
@@ -185,13 +184,13 @@ StoredRoute.fromJSON = function(obj) {
 
         case 'route':
             route = new Route.Route();
-            prop.path = prop.path.map(function(coordinate) {
+            prop.path = prop.path.map((coordinate) => {
                 let lat = coordinate.latitude;
                 let lon = coordinate.longitude;
                 return new Champlain.Coordinate({ latitude: lat,
                                                   longitude: lon });
             });
-            prop.turnPoints = prop.turnPoints.map(function(turnPoint) {
+            prop.turnPoints = prop.turnPoints.map((turnPoint) => {
                 let lat = turnPoint.coordinate.latitude;
                 let lon = turnPoint.coordinate.longitude;
 
@@ -209,9 +208,7 @@ StoredRoute.fromJSON = function(obj) {
             break;
 
         case 'places':
-            prop.forEach(function(p) {
-                places.push(Place.Place.fromJSON(p));
-            });
+            prop.forEach((p) => places.push(Place.Place.fromJSON(p)));
             break;
         }
     }
