@@ -19,27 +19,25 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const Lang = imports.lang;
-
 const _ = imports.gettext.gettext;
 
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 
-var TransitStopRow = new Lang.Class({
-    Name: 'TransitStopRow',
-    Extends: Gtk.ListBoxRow,
+var TransitStopRow = GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/transit-stop-row.ui',
     InternalChildren: [ 'nameLabel',
-                        'timeLabel' ],
+                        'timeLabel' ]
+}, class TransitStopRow extends Gtk.ListBoxRow {
 
-    _init: function(params) {
+    _init(params) {
         this.stop = params.stop;
         delete params.stop;
 
         this._final = params.final;
         delete params.final;
 
-        this.parent(params);
+        super._init(params);
 
         this._nameLabel.label = this.stop.name;
         this._timeLabel.label = this.stop.prettyPrint({ isFinal: this._final });
